﻿using Microsoft.AspNetCore.Mvc;
using PaydayBackend.Models;
using PaydayBackend.Services;

namespace PaydayBackend.Controllers;

[Route("v1/api/bank")]
[ApiController]
public class BankController : ControllerBase
{
    private readonly IAdminService _adminService;

    public BankController(IAdminService adminService)
    {
        _adminService = adminService;
    }
    
    /// <summary>
    /// Удаление ВСЕХ условий кредитования
    /// </summary>
    /// <response code="400">Банк не найден</response>
    [HttpDelete("banks/{bank_id}/loanterms")]
    public async Task<ActionResult> AddLoanTerm(long bankId)
    {
        var result = await _adminService.RemoveAllLoanTermsByBankId(bankId);
        return result == "OK" ? Ok() : BadRequest(result);
    }
    
    /// <summary>
    /// Добавление условия кредитования
    /// </summary>
    [HttpPost("banks/loanterms")]
    public async Task<ActionResult> AddLoanTerm([FromBody] LoanTerm loanTerm)
    {
        var result = await _adminService.AddLoanTerm(loanTerm);
        if (result != "OK")
            return BadRequest(result);
        
        return Ok();
    }

}