﻿using Microsoft.AspNetCore.Mvc;
using PaydayBackend.Models;
using PaydayBackend.Services;

namespace PaydayBackend.Controllers;

[Route("v1/public")]
[ApiController]
public class PublicController : ControllerBase
{
    private readonly IPublicService _publicService;

    public PublicController(IPublicService publicService)
    {
        _publicService = publicService;
    }

    /// <summary>
    /// Получение всех университетов
    /// </summary>
    [HttpGet("university")]
    public async Task<IEnumerable<UniversityDto>> GetAllUniversity()
    {
          return await _publicService.GetAllUniversity();
    }
    
    /// <summary>
    /// Получение университета по Id
    /// </summary>
    /// <response code="400">Университет не найден</response>
    [HttpGet("university/{id}")]
    public async Task<ActionResult<IEnumerable<UniversityDto>>> GetAllUniversityById(long id)
    {
        var result = await _publicService.GetAllUniversityById(id);
          
        if (result == null)
            return BadRequest();
          
        return Ok(result);
    }
    
    /// <summary>
    /// Получение всех направлений университета
    /// </summary>
    /// <response code="400">Университет не найден</response>
    [HttpGet("university/{id}/directions")]
    public async Task<ActionResult<IEnumerable<UniversityDirectionDto>>> GetAllUniversityDirectionByUniversityId(long id)
    {
          var result = await _publicService.GetAllUniversityDirectionByUniversityId(id);
          
          if (result == null)
              return BadRequest();
          
          return Ok(result);
    }

    /// <summary>
    /// Получение одно направление по Id
    /// </summary>
    /// <response code="400">Направление не найдено</response>
    [HttpGet("direction/{id}")]
    public async Task<ActionResult<IEnumerable<UniversityDirectionDto>>> GetDirectionById(long id)
    {
          var result = await _publicService.GetDirectionById(id);

          if (result == null)
              return BadRequest();
          
          return Ok(result);
    }
    
    /// <summary>
    /// Получение всех возможных кредитов по стоймости направления от каждого банка по одному
    /// </summary>
    /// <response code="400">Направление не найдено</response>
    [HttpGet("credit/direction/{directionId}")]
    public async Task<ActionResult<IEnumerable<Offer>>> GetOffers(long directionId)
    {
          var result = await _publicService.GetOffers(directionId);

          if (result == null)
              return BadRequest();
          
          return Ok(result);
    }
}