﻿using PaydayBackend.Utils;

namespace PaydayBackend.Services;

public interface IUserService
{
    public Task<string> UploadDocs(long userId, IFormFile file);
}

public class UserService : IUserService
{
    private readonly DatabaseContext _databaseContext;
    private readonly IStorageService _storageService;
    
    public UserService(DatabaseContext databaseContext, IStorageService storageService)
    {
        _databaseContext = databaseContext;
        _storageService = storageService;
    }
 
    public async Task<string> UploadDocs(long userId, IFormFile file)
    {
        string sizeValidator = FileHelper.ValidateMaxFileSize(file, 5, new []{".png"});
        if (sizeValidator != "OK")
            return sizeValidator;

        var fileStream = new MemoryStream();
        await file.CopyToAsync(fileStream);
        fileStream.Position = 0;
        string imageValidator = await FileHelper.ValidateImage(fileStream, null, 200, 200);
        if (imageValidator != "OK")
            return imageValidator;
                
        await FileHelper.CropImage(fileStream);

        var filename = "Doc" + userId + ".png";
        if (await _storageService.UploadFile(fileStream, "personal", filename))
        {
            // Send Request to bank
            return "ОК";
        }
        
        return "Image not uploaded";
    }
    
}